<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>WindowZoom</name>
    <message>
        <location filename="../WindowZoomInit.js" line="+2"/>
        <source>&amp;Window Zoom</source>
        <translation>Přiblížit pomocí &amp;okna</translation>
    </message>
</context>
</TS>
